package com.rnsocial.login.channel;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.os.Handler;
import android.os.Message;
import android.text.TextUtils;
import android.util.Log;

import com.alipay.sdk.app.AuthTask;
import com.google.gson.Gson;
import com.rnsocial.login.LoginCallBack;
import com.rnsocial.login.LoginManager;
import com.rnsocial.login.LoginService;
import com.rnsocial.login.enmus.LoginChannel;
import com.rnsocial.login.model.AuthResult;

import java.util.Map;

/**
 * Created by zhoujianxing on 2017/9/20.
 */

public class AlipayLogin implements LoginService {
    private static final String TAG = AlipayLogin.class.getSimpleName();

    private Activity mActivity;
    private LoginCallBack callBack;

    private static final int SDK_AUTH_FLAG = 2;

    @SuppressLint("HandlerLeak")
    private Handler mHandler = new Handler() {
        @SuppressWarnings("unused")
        public void handleMessage(Message msg) {
            switch (msg.what) {
                case SDK_AUTH_FLAG: {
                    @SuppressWarnings("unchecked")
                    AuthResult authResult = new AuthResult((Map<String, String>) msg.obj, true);
                    String resultStatus = authResult.getResultStatus();
                    Log.i(TAG,authResult.toString());

                    // 判断resultStatus 为“9000”且result_code
                    // 为“200”则代表授权成功，具体状态码代表含义可参考授权接口文档
                    if(TextUtils.equals(resultStatus,"9000") && TextUtils.equals(authResult.getResultCode(), "200")){
                        LoginManager.getInstance().LoginRequestCallBack(LoginChannel.Alipay,true,authResult,"登录成功");
                    }/*else if(TextUtils.equals(resultStatus,"6001")){
                        LoginManager.getInstance().LoginRequestCallBack(LoginChannel.Alipay,false,null,"取消登录");
                    }*/else {
                        LoginManager.getInstance().LoginRequestCallBack(LoginChannel.Alipay,false,null,"登录失败");
                    }
                    break;
                }
                default:
                    break;
            }

            AlipayLogin.this.callBack = null;
        }
    };

    public AlipayLogin(){}

    public AlipayLogin(Activity activity){
        init(activity,"");
    }

    @Override
    public void init(Activity activity, String appId, Object... objs) {
        this.mActivity = activity;
    }

    @Override
    public void loginRequestCallBack(boolean success, Object obj, String error) {
        if(this.callBack == null){
            return;
        }

        if(!success){
            this.callBack.onLoginError(error);
            this.callBack = null;
            return;
        }

        if(!(obj instanceof AuthResult)){
            this.callBack.onLoginError("登录失败");
            this.callBack = null;
            return;
        }

        this.callBack.onLoginSuccess(((AuthResult)obj).getAuthInfo());
        this.callBack = null;
    }

    @Override
    public void Login(Map<String, Object> loginArgs, LoginCallBack callBack) {
        this.callBack = callBack;

        if(!loginArgs.containsKey("sign") || TextUtils.isEmpty((String) loginArgs.get("sign"))){
            this.callBack.onLoginError("参数解析失败");
            return;
        }

       // if(TextUtils.isEmpty(mPid) || TextUtils.isEmpty(mAppId)
       //         || TextUtils.isEmpty(mRsa) || TextUtils.isEmpty(mTargetId)){
       //     this.callBack.onLoginError("支付宝登录初始化失败，请检查配置");
       //     return;
       // }
       //
       // Map<String, String> authInfoMap = OrderInfoUtil2_0.buildAuthInfoMap(mPid, mAppId, mTargetId, true);
       // String info = OrderInfoUtil2_0.buildOrderParam(authInfoMap);
       //
       // String sign = OrderInfoUtil2_0.getSign(authInfoMap, mRsa, true);
       // final String authInfo = info + "&" + sign;

        final String authInfo = (String)loginArgs.get("sign");
        Runnable authRunnable = new Runnable() {

            @Override
            public void run() {
                // 构造AuthTask 对象
                AuthTask authTask = new AuthTask(mActivity);
                // 调用授权接口，获取授权结果
                Map<String, String> result = authTask.authV2(authInfo, true);

                Message msg = new Message();
                msg.what = SDK_AUTH_FLAG;
                msg.obj = result;
                mHandler.sendMessage(msg);
            }
        };

        // 必须异步调用
        Thread authThread = new Thread(authRunnable);
        authThread.start();
    }
}
