package com.rnsocial.login.channel;

import android.app.Activity;

import com.google.gson.Gson;
import com.google.gson.JsonObject;
import com.rnsocial.login.LoginCallBack;
import com.rnsocial.login.LoginService;
import com.tencent.tauth.IUiListener;
import com.tencent.tauth.Tencent;

import org.json.JSONObject;

import java.util.Map;

/**
 * User : yh
 * Date : 17/6/6
 */

public class QQLogin implements LoginService{
    private final String SCOPE = "snsapi_userinfo";
    private Tencent mTencent;
    private Activity mActivity;
    private LoginCallBack callBack;

    public QQLogin(){

    }

    public QQLogin(Activity activity, String appId){
        init(activity,appId);
    }

    @Override
    public void init(Activity activity, String appId,Object... objs) {
        this.mActivity = activity;
        mTencent = Tencent.createInstance(appId,activity.getApplicationContext());
    }

    @Override
    public void loginRequestCallBack(boolean success,Object obj,String error) {
        if(this.callBack == null){return;}
        if(!success){
            this.callBack.onLoginError(error);
            this.callBack = null;
            return;
        }
        if(obj == null){
            this.callBack.onLoginError("登录失败");
            this.callBack = null;
            return;
        }
        try{
            JsonObject jObj = new JsonObject();
            jObj.addProperty("openid",((JSONObject)obj).getString("openid"));
            jObj.addProperty("access_token",((JSONObject)obj).getString("access_token"));

            String result = new Gson().toJson(jObj);
            this.callBack.onLoginSuccess(result);
            this.callBack = null;
        }catch (Exception e){
            e.printStackTrace();
        }
    }

    @Override
    public void Login(Map<String, Object> loginArgs, LoginCallBack callBack) {
        this.callBack = callBack;
        if(!IUiListener.class.isAssignableFrom(this.mActivity.getClass())){
            this.callBack.onLoginError("QQ登录初始化失败，请检查配置");
            this.callBack = null;
            return;
        }

        if(mTencent != null && !mTencent.isSessionValid()){
            mTencent.login(this.mActivity,SCOPE, (IUiListener) this.mActivity);
        }else{
            this.callBack.onLoginError("QQ登录初始化失败，请检查配置");
            this.callBack = null;
            return;
        }
    }
}
