package com.rnsocial.share;

import android.app.Activity;
import android.util.Log;
import android.widget.Toast;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableMap;

/**
 * User : yh
 * Date : 17/5/4
 */

public class ReactShareModule extends ReactContextBaseJavaModule {
    private final static String REACT_NAME = "ReactShare";

    public ReactShareModule(ReactApplicationContext reactContext) {
        super(reactContext);
    }

    @Override
    public String getName() {
        return REACT_NAME;
    }

    @ReactMethod
    public void share(final ReadableMap params, final Callback callback){
        final Activity activity = getCurrentActivity();
        if(params == null){
            Toast.makeText(activity, "分享参数异常", Toast.LENGTH_SHORT).show();
            return;
        }
        if(activity != null){
            activity.runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    try {
                        Share.share(activity, getShareContent(params), new ShareListener() {
                            @Override
                            public void onResult(boolean success, String result, Throwable throwable) {
                                if (callback == null){
                                    return;
                                }
                                WritableMap resultMap = Arguments.createMap();
                                resultMap.putBoolean("success", success);
                                resultMap.putString("message", result);
                                callback.invoke(resultMap);
                            }
                        });
                    }catch (Exception e){
                        Log.e(REACT_NAME,e.getMessage());
                    }
                }
            });
        }
    }

    @ReactMethod
    public void shareImg(final ReadableMap params, final Callback callback){
        final Activity activity = getCurrentActivity();
        if(params == null){
            Toast.makeText(activity, "分享参数异常", Toast.LENGTH_SHORT).show();
            return;
        }
        if(activity != null){

            activity.runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    try {
                        Share.shareImg(activity, params, new ShareListener() {
                            @Override
                            public void onResult(boolean success, String result, Throwable throwable) {
                                if (callback == null){
                                    return;
                                }
                                WritableMap resultMap = Arguments.createMap();
                                resultMap.putBoolean("success", success);
                                resultMap.putString("message", result);
                                callback.invoke(resultMap);
                            }
                        });
                    }catch (Exception e){
                        Log.e(REACT_NAME,e.getMessage());
                    }
                }
            });
        }
    }

    private ShareContent getShareContent(ReadableMap params){
        ShareContent shareContent = new ShareContent();
        if(params.hasKey("title")){
            shareContent.title = params.getString("title");
        }
        if(params.hasKey("url")){
            shareContent.url = params.getString("url");
        }
        if(params.hasKey("content")){
            shareContent.content = params.getString("content");
        }
        if(params.hasKey("image")){
            shareContent.image = params.getString("image");
        }
        if(params.hasKey("useContentTitle")){
            shareContent.useContentTitle = params.getBoolean("useContentTitle");
        }
        if(params.hasKey("showPoster")){
            shareContent.showPoster = true;
        }
        return shareContent;
    }

}
