package com.rnsocial.share;

import android.app.Activity;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Color;
import android.util.Base64;

import com.facebook.react.bridge.ReadableMap;
import com.rnsocial.SocialConfig;
import com.umeng.socialize.ShareAction;
import com.umeng.socialize.UMShareAPI;
import com.umeng.socialize.UMShareListener;
import com.umeng.socialize.bean.PlatformName;
import com.umeng.socialize.bean.SHARE_MEDIA;
import com.umeng.socialize.media.UMImage;
import com.umeng.socialize.media.UMWeb;
import com.umeng.socialize.shareboard.ShareBoardConfig;
import com.umeng.socialize.shareboard.SnsPlatform;
import com.umeng.socialize.utils.ShareBoardlistener;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

/**
 * User : yh
 * Date : 17/5/4
 */

public class Share {
    private static SHARE_MEDIA[] getShareMedias() {
        List<SHARE_MEDIA> medias = new ArrayList<SHARE_MEDIA>();
        for (ShareChannel channel : SocialConfig.getShareChannels()) {
            if (channel == ShareChannel.Weibo) {
                medias.add(SHARE_MEDIA.SINA);
                PlatformName.SINA = "新浪微博";
            } else if (channel == ShareChannel.Weixin) {
                medias.add(SHARE_MEDIA.WEIXIN);
                PlatformName.WEIXIN = "微信好友";
            } else if (channel == ShareChannel.WeixinCycle) {
                medias.add(SHARE_MEDIA.WEIXIN_CIRCLE);
                PlatformName.WEIXIN_CIRCLE = "朋友圈";
            } else if (channel == ShareChannel.QQ) {
                medias.add(SHARE_MEDIA.QQ);
                PlatformName.QQ = "QQ好友";
            } else if (channel == ShareChannel.QZONE) {
                medias.add(SHARE_MEDIA.QZONE);
            } else if (channel == ShareChannel.AliPayShare) {
                medias.add(SHARE_MEDIA.ALIPAY);
            } else if (channel == ShareChannel.DingTalk) {
                medias.add(SHARE_MEDIA.DINGTALK);
            }
        }
        return medias.toArray(new SHARE_MEDIA[medias.size()]);
    }

    public static void share(final Activity mContext, final ShareContent content, final ShareListener listener) {
        ShareBoardConfig boardConfig = new ShareBoardConfig();
        boardConfig.setTitleText("分享到");
        boardConfig.setCancelButtonText("取消");
        boardConfig.setTitleTextColor(Color.BLACK);
        boardConfig.setCancelButtonTextColor(Color.BLACK);
        boardConfig.setShareboardBackgroundColor(Color.WHITE);
        boardConfig.setMenuItemBackgroundColor(Color.TRANSPARENT);
        boardConfig.setMenuItemBackgroundShape(ShareBoardConfig.BG_SHAPE_CIRCULAR);
        boardConfig.setIndicatorVisibility(false);
        ShareAction sa = new ShareAction(mContext);

        sa.setDisplayList(getShareMedias());
        if (content.showPoster) {
            sa.addButton("生成海报", "umeng_sharebutton_poster", "poster_icon", "poster_icon");// 自定义按钮
        }
//        sa.setDisplayList(getShareMedias());
        sa.setShareboardclickCallback(new ShareBoardlistener() {
            @Override
            public void onclick(SnsPlatform snsPlatform, SHARE_MEDIA share_media) {

                if (share_media == null) {
                    //根据key来区分自定义按钮的类型，并进行对应的操作
                    if (snsPlatform.mKeyword.equals("umeng_sharebutton_poster")) {
                        listener.onResult(true, "createPoster", null);
                        return;
                    }
                }

                String resultTitle = content.useContentTitle && (share_media == SHARE_MEDIA.WEIXIN_CIRCLE) ? content.content : content.title;
                UMWeb web = new UMWeb(content.url);
                UMImage img = new UMImage(mContext, content.image);
                img.compressStyle = UMImage.CompressStyle.SCALE;
                web.setDescription(content.content);
                web.setTitle(resultTitle);
                web.setThumb(img);
                new ShareAction(mContext).setPlatform(share_media)
                        .setCallback(new UMShareListener() {
                            @Override
                            public void onStart(SHARE_MEDIA share_media) {
                            }

                            @Override
                            public void onResult(SHARE_MEDIA share_media) {
                                listener.onResult(true, "", null);
                            }

                            @Override
                            public void onError(SHARE_MEDIA share_media, Throwable throwable) {
                                listener.onResult(false, throwable.getMessage(), throwable);
                            }

                            @Override
                            public void onCancel(SHARE_MEDIA share_media) {
                                Throwable throwable = new Throwable("取消分享");
                                listener.onResult(false, "取消分享", throwable);
                            }
                        }).withText(content.title)
                        .withSubject(content.content)
                        .withMedia(web)
                        .share();
            }
        }).open(boardConfig);
    }

    public static void shareImg(final Activity mContext, final ReadableMap params, final ShareListener listener) {
        SHARE_MEDIA share_media = params.getString("platformType").equals("1")?SHARE_MEDIA.WEIXIN:SHARE_MEDIA.WEIXIN_CIRCLE;
//        UMImage image = new UMImage(mContext, new File(params.getString("imgPath")));
        String imgBase64 = params.getString("imgBase64");
        Bitmap bitmap = null;
        try {
            byte[] bitmapArray = Base64.decode(imgBase64, Base64.DEFAULT);
            bitmap = BitmapFactory.decodeByteArray(bitmapArray, 0, bitmapArray.length);
        } catch (Exception e) {
            e.printStackTrace();
        }
        UMImage image = new UMImage(mContext, bitmap);

        new ShareAction(mContext).setPlatform(share_media)
                .setCallback(new UMShareListener() {
                    @Override
                    public void onStart(SHARE_MEDIA share_media) {
                    }

                    @Override
                    public void onResult(SHARE_MEDIA share_media) {
                        listener.onResult(true, "", null);
                    }

                    @Override
                    public void onError(SHARE_MEDIA share_media, Throwable throwable) {
                        listener.onResult(false, throwable.getMessage(), throwable);
                    }

                    @Override
                    public void onCancel(SHARE_MEDIA share_media) {
                        Throwable throwable = new Throwable("取消分享");
                        listener.onResult(false, "取消分享", throwable);
                    }
                }).withText("分享")
                .withMedia(image)
                .share();
    }
}
