#import "RNLoginManager.h"
#import <TencentOpenAPI/TencentOAuth.h>
#import "WXApi.h"
#import <AlipaySDK/AlipaySDK.h>

static NSString *scope = @"snsapi_userinfo";
static NSString *state = @"terminus_snsapi_userinfo";

@interface RNLoginManager() <TencentSessionDelegate,WXApiDelegate>

@property(nonatomic,strong)TencentOAuth *tencentOAuth;

@end

@implementation RNLoginManager
{
    NSString *_wechatAppId;
    NSString *_qqAppId;
    NSString *_alipayAppId;
//    NSString *_alipayPid;
    NSString *_alipayAppScheme;
//    NSString *_alipayRsa2PrivateKey;

    ThirdLoginResult _loginResult;
}

- (instancetype)init{
    self = [super init];
//    if(self){
//        [RNWXApiManager sharedManager].delegate = self;
//    }
    return self;
}

+ (id) shareInstance{
    static RNLoginManager *_loginInstance = nil;
    static dispatch_once_t once_t;
    dispatch_once(&once_t, ^{
        if(!_loginInstance){
            _loginInstance = [[self alloc] init];
        }
    });
    return _loginInstance;
}


-(void)initWechatLogin:(NSString*)appId{
    _wechatAppId = appId;
}

-(void)initQQLogin:(NSString*)appId{
    _qqAppId = appId;
}

-(void)initAlipayLogin:(NSString*)appId
                scheme:(NSString*)scheme{
    _alipayAppId = appId;
    _alipayAppScheme = scheme;
}

- (void)alipayLogin:(ThirdLoginResult)result
               sign:(NSString*) sign{
    
    if(sign.length <= 0){
        result(NO,nil,@"参数解析失败");
        return;
    }
    
    _loginResult = [result copy];
    [[AlipaySDK defaultService] auth_V2WithInfo:sign
                                     fromScheme:_alipayAppScheme
                                       callback:^(NSDictionary *resultDic){
//                                         解析 auth code
                                          NSString *result = resultDic[@"result"];
                                          NSString *authCode = nil;
                                          NSMutableDictionary *dict = [NSMutableDictionary dictionary];
                                           
                                           if (result.length>0) {
                                               NSArray *resultArr = [result componentsSeparatedByString:@"&"];
                                               for (NSString *param in resultArr) {
                                                   if (param && param.length) {
                                                       NSArray *parArr = [param componentsSeparatedByString:@"="];
                                                       if (parArr.count == 2) {
                                                           [dict setObject:parArr[1] forKey:parArr[0]];
                                                       }
                                                   }
                                               }
                                           }
                                           
                                           
                                           if (dict.allKeys.count >0 && [dict[@"result_code"] isEqualToString:@"200"]) {
                                               NSData *data=[NSJSONSerialization dataWithJSONObject:dict options:NSJSONWritingPrettyPrinted error:nil];
                                               NSString *jsonStr=[[NSString alloc]initWithData:data encoding:NSUTF8StringEncoding];
                                               _loginResult(YES,jsonStr,@"登录成功");
                                               
                                           }else{
                                               _loginResult(NO,nil,@"登录失败");
                                           }

                                       }];
                                             
}

- (void)weChatLogin:
            (ThirdLoginResult)result{
    //_wechatAppId = appId;
    if(_wechatAppId == nil){
        result(NO,nil,@"请先初始化登录配置");
        return;
    }
    _loginResult = [result copy];
    SendAuthReq* req = [[SendAuthReq alloc] init];
    req.scope = scope;
    req.state = state;
    [WXApi sendReq:req completion:^(BOOL success) {}];
}

-(void) qqLogin:
         (ThirdLoginResult)result{
    //_qqAppId = appId;
    if(_qqAppId == nil){
        result(NO,nil,@"请先初始化登录配置");
        return;
    }
    _loginResult = [result copy];
    NSArray* permissions = [NSArray arrayWithObjects:
                            kOPEN_PERMISSION_GET_USER_INFO,
                            kOPEN_PERMISSION_GET_SIMPLE_USER_INFO,
                            nil];
    [self.tencentOAuth authorize:permissions inSafari:NO];
}

- (void)tencentDidNotLogin:(BOOL)cancelled{
    _loginResult(NO,nil,@"取消登录");
}

-(void)tencentDidNotNetWork{
    _loginResult(NO,nil,@"网络异常");
}

-(void)tencentDidLogin{
    __block __weak typeof(_qqAppId) _weakqqAppId = _qqAppId;
    __block __weak typeof(_tencentOAuth) _weakTencentOAuth = _tencentOAuth;
    if (_tencentOAuth.accessToken && 0 != _tencentOAuth.accessToken) {
        NSMutableDictionary *dict = [NSMutableDictionary dictionary];
        //[dict setObject:_tencentOAuth.appId forKey:@"appId"];
        [dict setObject:_tencentOAuth.accessToken forKey:@"access_token"];
        [dict setObject:_tencentOAuth.openId forKey:@"openid"];
        // [dict setObject:_tencentOAuth.unionid forKey:@"unionid"];
        NSData *data=[NSJSONSerialization dataWithJSONObject:dict options:NSJSONWritingPrettyPrinted error:nil];
        NSString *jsonStr=[[NSString alloc]initWithData:data encoding:NSUTF8StringEncoding];
        
        _loginResult(YES,jsonStr,@"登录成功");
    }
}

-(BOOL)handleQQLoginUrl:(NSURL *)url{
    [TencentOAuth HandleOpenURL:url];
    return YES;
}

-(BOOL)handleWechatLoginUrl:(NSURL *)url{
    [WXApi handleOpenURL:url delegate:self];
    return YES;
}

- (void)onResp:(BaseResp *)resp {
    if(resp.errCode == 0){
        if ([resp isKindOfClass:[SendAuthResp class]]) {
            SendAuthResp *authResp = (SendAuthResp *)resp;
            _loginResult(YES,authResp.code,@"登录成功");
        }
    }else if(resp.errCode == -2){
        _loginResult(NO,nil,@"取消登录");
    }else if(resp.errCode == -4){
        _loginResult(NO,nil,@"用户拒绝授权");
    }
}

-(BOOL)handleAlipayLoginUrl:(NSURL *)url{
    return YES;
}

-(TencentOAuth *)tencentOAuth{
    if (!_tencentOAuth) {
        _tencentOAuth =[[TencentOAuth alloc] initWithAppId:_qqAppId andDelegate:self];
    }
    return _tencentOAuth;
}

-(void) login:(id)data
       result:(ThirdLoginResult) block{
    NSInteger _channel = ((NSString*)data[@"channel"]).integerValue;
    NSString *_sign = ((NSString*)data[@"sign"]);
    if(_channel == RNLoginChannelQQ){
        [self qqLogin:block];
    }else if(_channel == RNLoginChannelWechat){
        [self weChatLogin:block];
    }else if(_channel == RNLoginChannelAlipay){
        [self alipayLogin:block sign:_sign];
    }
    else{
        block(NO,nil,@"登录渠道错误");
    }
}

@end

