#import "RNPayManager.h"
#import <AlipaySDK/AlipaySDK.h>
#import "WXApi.h"
#import "RNSocialNativeBridgeManager.h"
#import "UPPaymentControl.h"
#import "QQWApplication.h"
#import "QQWalletSDK.h"
//#import <BaiduWallet_Portal/BDWalletSDKMainManager.h>
//#import "RNBaiduPayViewController.h"

NSString *const PayAlipayURLScheme = @"alipay://";

@interface RNPayManager () <WXApiDelegate>

//@property (nonatomic, strong) RNBaiduPayViewController *baiduVc;


@end

@implementation RNPayManager

+ (id)shareInstance{
    static RNPayManager *_instance = nil;
    static dispatch_once_t _once;
    dispatch_once(&_once,^{
        if(!_instance){
            _instance = [[self alloc] init];
        }});
    return _instance;
}

- (instancetype)init {
    self = [super init];
    if(self){
        _unionPayMode = @"00";

    }
    return self;
}

-(void)wechatInit:(NSString *)appId
	universalLink:(NSString*)universalLink {
    [self setWeixinAppId:appId];
    [WXApi registerApp:appId universalLink: universalLink];
    
    //在register之前打开log, 后续可以根据log排查问题
//[WXApi startLogByLevel:WXLogLevelDetail logBlock:^(NSString *log) {
//    NSLog(@"WeChatSDK: %@", log);
//}];
//
////调用自检函数
//[WXApi checkUniversalLinkReady:^(WXULCheckStep step, WXCheckULStepResult* result) {
//    NSLog(@"%@, %u, %@, %@", @(step), result.success, result.errorInfo, result.suggestion);
//}];
}

- (void)aliInit:(NSString *)scheme{
    [self setAliScheme:scheme];
}

- (void)qqWalletInit:(NSString *)appid scheme:(NSString *)scheme name:(NSString *)name
{
    _qqAppId = appid;
    [QQWalletSDK registerQQWalletApplication:appid
                                   urlScheme:scheme
                                        name:name];
}

- (void)unionInit:(NSString *)scheme
{
    [self setUnionScheme:scheme];
}

- (Boolean) checkSupport:(RNPayChannel)channel result:(void (^)(BOOL, NSString *, NSString *))block{
    Boolean support = false;
    switch (channel) {
        case RNPayChannelAliPay:
            if(![[UIApplication sharedApplication] canOpenURL:[NSURL URLWithString:PayAlipayURLScheme]]){
                block(NO, @"alipay.not.install", @"未安装支付宝客户端");
            }else{
                support = true;
            }
            break;
        case RNPayChannelWechat:
            if(![WXApi isWXAppInstalled]){
                block(NO, @"wechat.not.install", @"未安装微信客户端");
            }else{
                support = true;
            }
            break;
        case RNPayChannelUnionPay:
            
//            if (![[UPPaymentControl defaultControl] isPaymentAppInstalled]) {
//                block(NO, @"unionpay.not.install", @"未安装银联支付");
//            }
//            else {
                support = true;
//            }
            break;
        case RNPayChannelQQWalletPay:
            
            if (![QQWalletSDK isSupportQQWallet]) {
                block(NO, @"unionpay.not.install", @"未安装QQ支付");
            }
            else {
                support = true;
            }
            break;
        default:
            block(NO, @"pay.error", @"请选择正确的支付渠道");
            break;
    }
    return support;
}

-(void) pay:(id)data result:(void (^)(BOOL, NSString *, NSString *))block{
    NSInteger _channel = ((NSString*)data[@"channel"]).integerValue;
    if(![self checkSupport:_channel result:block]){
        return;
    }
    if(_channel == RNPayChannelAliPay){
        [self aliPay:data result:block];
    }else if(_channel == RNPayChannelWechat){
        [self wechat:data result:block];
    }else if(_channel == RNPayChannelUnionPay) {
        [self unionPay:data result:block];
    }else if(_channel == RNPayChannelQQWalletPay) {
        [self QQPay:data result:block];
    }else{
        block(NO,@"pay.error",@"请选择正确的支付渠道");
    }
}


- (BOOL)handlePayOpenURL:(NSURL *)url{
    
    if ([[url host] isEqualToString:@"safepay"]) { // 阿里支付
        [self alipayCallback:url];
    }else if ([[url host] isEqualToString:@"uppayresult"]) {// 银联支付
        [self unionPayCallback:url];
    }else  if ([[url absoluteString] hasPrefix:[QQWApplication sharedApplication].urlSchemePrefix]) {      // QQ支付
        [QQWalletSDK QQWalletSDKHanldeApplication:nil
                                          openURL:url
                                sourceApplication:nil
                                       annotation:nil];
        
    }else{
        [WXApi handleOpenURL:url delegate:self]; // 微信支付
    }
    return YES;
   
}

#pragma wxPay

- (void) wechat:(id)data result:(void (^)(BOOL, NSString *, NSString *))block{
    PayReq *request = [[PayReq alloc] init];
    request.partnerId = data[@"partnerId"];
    request.prepayId = data[@"prepayId"];
    request.package = data[@"package"];
    request.nonceStr = data[@"nonceStr"];
    request.timeStamp = ((NSString*)data[@"timeStamp"]).longLongValue;
    request.sign = data[@"sign"];
    [WXApi sendReq:request completion:nil];
}

- (void)onResp:(BaseReq *)resp {

    if ([resp isKindOfClass:[PayResp class]]) {
        [self WXApiManagerDidRecvPay:(PayResp *)resp];
    }
}

- (void)WXApiManagerDidRecvPay:(PayResp *)resp
{
    PayResp *response = (PayResp *) resp;
    switch (response.errCode) {
        case WXSuccess:
            [RNPayNativeBridge registerPayResult:true];
            break;
        default:
            [RNPayNativeBridge registerPayResult:false];
            break;
    }
}


#pragma mark - UnionPay

- (void)unionPay:(id)data result:(void (^)(BOOL, NSString *, NSString *))block {
    NSAssert(_unionScheme, @"设置支付回调的URL scheme");
    NSString *tn = data[@"sign"];
    [[UPPaymentControl defaultControl] startPay:tn
                                     fromScheme:_unionScheme
                                           mode:_unionPayMode
                                 viewController:[UIApplication sharedApplication].keyWindow.rootViewController];

}


- (void)unionPayCallback:(NSURL *)url {

    [[UPPaymentControl defaultControl] handlePaymentResult:url
                                             completeBlock:^(NSString *code, NSDictionary *data) {
                                                 
                                                 //结果code为成功时，先校验签名，校验成功后做后续处理
                                                 if([code isEqualToString:@"success"]) {
                                                     
                                                     [RNPayNativeBridge registerPayResult:true];
                                                     
                                                     
                                                 }
                                                 else if([code isEqualToString:@"fail"]) {
                                                     //交易失败
                                                     [RNPayNativeBridge registerPayResult:false];
                                                 } else if([code isEqualToString:@"cancel"]) {
                                                     //交易取消
                                                     [RNPayNativeBridge registerPayResult:false];
                                                 }
                                             }];
    
}



#pragma mark - AliPay

- (void) aliPay:(id)data result:(void (^)(BOOL, NSString *, NSString *))block{
    NSAssert(_aliScheme, @"设置支付回调的URL scheme");
    NSString *sign = data[@"sign"];
    [[AlipaySDK defaultService] payOrder:sign fromScheme:_aliScheme callback:^(NSDictionary *resultDic){
        // resultstatus == 9000 表示支付成功
        NSString *resultStatus = resultDic[@"resultStatus"];
        BOOL success = [resultStatus isEqualToString:@"9000"];
        [RNPayNativeBridge registerPayResult:success];
    }];
}

- (void)alipayCallback:(NSURL *)url {

    [[AlipaySDK defaultService] processOrderWithPaymentResult:url standbyCallback:^(NSDictionary *resultDic) {
        //BOOL success = resultDic[@"success"];
        NSArray *payDictKeys = [(NSDictionary*)resultDic allKeys];
        NSString *resultStatus = @"-1";
        if([payDictKeys containsObject:@"resultStatus"]){
            resultStatus = resultDic[@"resultStatus"];
        }
        BOOL success = [resultStatus isEqualToString:@"9000"];
        [RNPayNativeBridge registerPayResult:success];
    }];
    

}


#pragma mark QQPay

- (void) QQPay:(id)data result:(void (^)(BOOL, NSString *, NSString *))block{
    NSArray *payDictKeys = [(NSDictionary*)data allKeys];
    if([payDictKeys containsObject:@"bargainorId"]
       &&[payDictKeys containsObject:@"tokenId"]
       && [payDictKeys containsObject:@"nonce"]
       && [payDictKeys containsObject:@"sign"]
       &&_qqAppId){
        [QQWalletSDK startPayWithAppId:_qqAppId
                           bargainorId:data[@"bargainorId"]
                               tokenId:data[@"tokenId"]
                             signature:data[@"sign"]
                                 nonce:data[@"nonce"]
                            completion:^(QWMessage *message, NSError *error) {
                                
                                if(error){
                                    [RNPayNativeBridge registerPayResult:false];

                                }else{
                                    [RNPayNativeBridge registerPayResult:true];
                                }
        }];
        
    }
    
}


@end
