#import "RNShareConfig.h"
#import <UShareUI/UShareUI.h>
#import "RNLoginManager.h"
#import <UMShare/UMShare.h>

@implementation RNShareResponse

- (NSDictionary *)serialization {
    return @{
             @"success": @(_success),
             @"message": _message?:@""
             };
}

@end

@interface RNShareParam : NSObject

@property(nonatomic, copy) NSString *title;
@property(nonatomic, copy) NSString *content;
@property(nonatomic, copy) NSString *image;
@property(nonatomic, copy) NSString *url;
@property(nonatomic, assign) BOOL useContentTitle;
@property(nonatomic, assign) BOOL showPoster;


@end

@implementation RNShareParam
@end

@interface RNShareConfig()
@property(nonatomic,strong) RNShareParam *shareParams;
@end

@implementation RNShareConfig {
    RNShareResponseCallback _callback;
}

+ (instancetype) shareInstance{
    static RNShareConfig * _shanreInstance;
    static dispatch_once_t once_t;
    dispatch_once(&once_t, ^{
        if(!_shanreInstance){
            _shanreInstance = [[RNShareConfig alloc] init];
        }
    });
    return _shanreInstance;
}

- (instancetype) init
{
    self = [super init];
    return self;
}

//- (void) setUmengAppKey:(NSString *)umengAppKey{
//    _umengAppKey = [umengAppKey copy];
//    [[UMSocialManager defaultManager] setUmSocialAppkey:_umengAppKey];
//}
//
//- (void) enableShareWithumengAppKey:(NSString *)umengAppKey snsNames:(NSArray *)snsNames{
//    [self setUmengAppKey:umengAppKey];
//    [self setSnsNames:snsNames];
//}

- (void) shareHandler:(NSDictionary *)data  callback:(RNShareResponseCallback)callback;{
    if (callback){
        _callback = [callback copy];
    }
    RNShareParam *shareParam = [self formatParams:data];
    [self setShareParams:shareParam];
    if([_snsNames count] > 0){
        [UMSocialUIManager setPreDefinePlatforms:_snsNames];
    }
    [UMSocialUIManager setPreDefinePlatforms:_snsNames];
    [UMSocialShareUIConfig shareInstance].shareTitleViewConfig.shareTitleViewTitleString = @"分享到";
    [UMSocialShareUIConfig shareInstance].shareTitleViewConfig.shareTitleViewTitleColor = UIColor.blackColor;
    [UMSocialShareUIConfig shareInstance].shareTitleViewConfig.shareTitleViewBackgroundColor = UIColor.whiteColor;
    [UMSocialShareUIConfig shareInstance].shareContainerConfig.isShareContainerHaveGradient = NO;
    [UMSocialShareUIConfig shareInstance].shareCancelControlConfig.shareCancelControlText = @"取消";
    [UMSocialShareUIConfig shareInstance].shareCancelControlConfig.shareCancelControlTextColor = UIColor.blackColor;
    [UMSocialShareUIConfig shareInstance].shareCancelControlConfig.shareCancelControlBackgroundColor = UIColor.whiteColor;
    [UMSocialShareUIConfig shareInstance].sharePageControlConfig.isShow = false;
    [UMSocialShareUIConfig shareInstance].sharePageScrollViewConfig.shareScrollViewPageBGColor = UIColor.whiteColor;
    [UMSocialShareUIConfig shareInstance].sharePageScrollViewConfig.shareScrollViewBackgroundColor = UIColor.whiteColor;
    __weak typeof(self) weakSelf = self;
	
    // 加入生成海报的操作
    // @see http://dev.umeng.com/social/ios/进阶文档#6
    if (shareParam.showPoster) {
		[UMSocialUIManager addCustomPlatformWithoutFilted:UMSocialPlatformType_UserDefine_Begin+2
                                     withPlatformIcon:[UIImage imageNamed:@"poster_icon"]
                                     withPlatformName:@"生成海报"];
	}
    [UMSocialShareUIConfig shareInstance].sharePageGroupViewConfig.sharePageGroupViewPostionType = UMSocialSharePageGroupViewPositionType_Bottom;
    [UMSocialShareUIConfig shareInstance].sharePageScrollViewConfig.shareScrollViewPageItemStyleType = UMSocialPlatformItemViewBackgroudType_None;
    [UMSocialUIManager showShareMenuViewInWindowWithPlatformSelectionBlock:^(UMSocialPlatformType platformType, NSDictionary *userInfo) {
        //在回调里面获得点击的
        if (platformType == UMSocialPlatformType_UserDefine_Begin+2) {
            NSLog(@"do your operation for copy");
			if (!_callback){
                return;
            }
            RNShareResponse *response = [[RNShareResponse alloc] init];
            response.success = YES;
            response.message = @"createPoster";
            _callback(response);
        }
        else{
            NSString *resultTitle =shareParam.useContentTitle && (platformType == UMSocialPlatformType_WechatTimeLine) ? shareParam.content :shareParam.title ;

            UMShareWebpageObject *msg = [UMShareWebpageObject shareObjectWithTitle:resultTitle
                                                                            descr:shareParam.content
                                                                        thumImage:shareParam.image];
            msg.webpageUrl = shareParam.url;
            UMSocialMessageObject *messageObject = [UMSocialMessageObject messageObject];
            messageObject.shareObject = msg;
            [[UMSocialManager defaultManager] shareToPlatform:platformType messageObject:messageObject currentViewController:[RNShareConfig getRootViewController] completion:^(id result, NSError *error) {
                [weakSelf shareCallback:result error:error];
            }];
        }
    }];
}

- (void) shareImgHandler:(NSDictionary *)data  callback:(RNShareResponseCallback)callback;{
    if (callback){
        _callback = [callback copy];
    }
    __weak typeof(self) weakSelf = self;
    NSInteger platformType = [[data objectForKey:@"platformType"] intValue];
    NSString *imgBase64 = [data objectForKey:@"imgBase64"];
    NSData *imageData = [[NSData alloc] initWithBase64EncodedString:imgBase64 options:NSDataBase64DecodingIgnoreUnknownCharacters];
    UIImage *image = [UIImage imageWithData:imageData];
    UIImage *png = UIImagePNGRepresentation(image);
	
	//创建分享消息对象
    UMSocialMessageObject *messageObject = [UMSocialMessageObject messageObject];
    //创建图片内容对象
    UMShareImageObject *shareObject = [[UMShareImageObject alloc] init];
    [shareObject setShareImage:png];
    //分享消息对象设置分享内容对象
    messageObject.shareObject = shareObject;
    //调用分享接口
    [[UMSocialManager defaultManager] shareToPlatform:platformType messageObject:messageObject currentViewController:[RNShareConfig getRootViewController] completion:^(id result, NSError *error) {
                [weakSelf shareCallback:result error:error];
            }];
}


- (void)shareCallback:(id)result error:(NSError *)error{
    if (!_callback){
        return;
    }
    RNShareResponse *response = [[RNShareResponse alloc] init];
    if (error){
        response.success = NO;
        response.message = [error description];
    } else if([result isKindOfClass:[UMSocialShareResponse class]]){
        UMSocialShareResponse *shareResponse = (UMSocialShareResponse *)result;
        response.success = YES;
        response.message = shareResponse.message;
    } else {
        response.success = YES;
        response.message = [result description];
    }
    _callback(response);
}

- (void)initWechat:(NSString*)appKey appSecret:(NSString*)appSecret redirect:(NSString*)redirect{
    [[UMSocialManager defaultManager] setPlaform:UMSocialPlatformType_WechatSession appKey:appKey appSecret:appSecret redirectURL:redirect];
    [[RNLoginManager shareInstance] initWechatLogin:appKey];
}

- (void)initQQ:(NSString*)appKey appSecret:(NSString*)appSecret redirect:(NSString*)redirect{
    [[UMSocialManager defaultManager] setPlaform:UMSocialPlatformType_QQ appKey:appKey appSecret:appSecret redirectURL:redirect];
    [[RNLoginManager shareInstance] initQQLogin:appKey];
}

- (void)initAli:(NSString*)appKey appSecret:(NSString*)appSecret redirect:(NSString*)redirect{
    [[UMSocialManager defaultManager] setPlaform: UMSocialPlatformType_APSession appKey:appKey appSecret:appSecret redirectURL:redirect];
    
    [[RNLoginManager shareInstance] initAlipayLogin:appKey scheme:redirect];
}

- (void)initSina:(NSString*)appKey appSecret:(NSString*)appSecret redirect:(NSString*)redirect{
    [[UMSocialManager defaultManager] setPlaform:UMSocialPlatformType_Sina appKey:appKey appSecret:appSecret redirectURL:redirect];
}

- (void)initAliPayShare:(NSString *)appKey appSecret:(NSString*)appSecret redirect:(NSString*)redirect {
    [[UMSocialManager defaultManager] setPlaform:UMSocialPlatformType_APSession appKey:appKey appSecret:appSecret redirectURL:redirect];
}

- (void)initDingTalkShare:(NSString *)appKey appSecret:(NSString *)appSecret redirect:(NSString *)redirect {
    [[UMSocialManager defaultManager] setPlaform:UMSocialPlatformType_DingDing appKey:appKey appSecret:UIApplicationLaunchOptionsSourceApplicationKey redirectURL:redirect];
}

+ (UIViewController *)getRootViewController {
    UIViewController *viewController = [UIApplication sharedApplication].keyWindow.rootViewController;
    if ([viewController isKindOfClass:[UINavigationController class]]) {
        return ((UINavigationController *) viewController).visibleViewController;
    }
    return viewController;
}

- (RNShareParam *) formatParams:(NSDictionary *)param{
    RNShareParam *shareParam = [[RNShareParam alloc] init];
    [shareParam setImage:param[@"image"]];
    [shareParam setUrl:param[@"url"]];

    NSString *content = param[@"content"];
    if (content) {
        [shareParam setContent:content];
    }

    if ([param.allKeys containsObject:@"useContentTitle"]) {
        [shareParam setUseContentTitle:param[@"useContentTitle"]];
    }
	
    if ([param.allKeys containsObject:@"showPoster"]) {
        [shareParam setShowPoster:param[@"showPoster"]];
    }
    
    NSString *title = param[@"title"];
    if (title) {
        [shareParam setTitle:title];
    }
    return shareParam;
}





@end
